@@ -374,7 +374,7 @@ bm.lik=function(phy, dat, SE = NA, model=c("BM", "OU", "EB", "trend", "lambda",
         #print(datC)
         parsC=as.numeric(rep(sigsq, n.cache$z))
 
-        out = .Call("bm_direct", dat = datC, pars = parsC, package = "geiger")
+        out = .Call("bm_direct", dat = datC, pars = parsC, PACKAGE = "geiger")
         loglik <- sum(out$lq)
 		if(is.na(loglik)) loglik=-Inf
         attr(loglik, "ROOT.MAX")=out$initM[datC$root]
